[devel] Imported from libpng-1.4.0rc02.tar
diff --git a/png.h b/png.h
index 613210d..4e1e930 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.0beta110 - December 13, 2009
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.0beta110 - December 13, 2009: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -131,7 +131,8 @@
  *    1.4.0beta15-36          14    10400  14.so.0.0[.0]
  *    1.4.0beta37-87          14    10400  14.so.14.0[.0]
  *    1.4.0rc01               14    10400  14.so.14.0[.0]
- *    1.4.0beta88-110         14    10400  14.so.14.0[.0]
+ *    1.4.0beta88-109         14    10400  14.so.14.0[.0]
+ *    1.4.0rc02               14    10400  14.so.14.0[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -163,7 +164,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta110, December 13, 2009, are
  * Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -281,7 +282,7 @@
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.4.0beta110 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -337,9 +338,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.0beta110"
+#define PNG_LIBPNG_VER_STRING "1.4.0rc02"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.0beta110 - December 13, 2009\n"
+   " libpng version 1.4.0rc02 - December 20, 2009\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -352,7 +353,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  110
+#define PNG_LIBPNG_VER_BUILD  02
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -1341,7 +1342,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_4_0beta110;
+typedef png_structp version_1_4_0rc02;
 
 typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.0beta110 - December 13, 2009
+ * libpng version 1.4.0rc02 - December 20, 2009
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.0beta110 - December 13, 2009: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.0rc02 - December 20, 2009: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -163,7 +164,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta110, December 13, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0rc02, December 20, 2009, are
  * Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -281,7 +282,7 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.4.0beta110 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.0rc02 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *